@@ -40,6 +40,7 @@ if [ "$FOP_HYPHENATION_PATH" ]; then
 fi
 find_jars fop
 
+LOG_OPTION=-Dorg.apache.commons.logging.Log=org.apache.fop.util.CommandLineLogger
+# LOG_DEBUG_OPTION=-Dlog4j.debug
 
-
-run_java $HEADLESS org.apache.fop.cli.Main "$@"
+run_java $HEADLESS $LOG_OPTION org.apache.fop.cli.Main "$@"
